@@ -63,6 +63,7 @@ static gboolean zenity_info_active;
 static gboolean zenity_file_active;
 static gboolean zenity_file_directory;
 static gboolean zenity_file_save;
+static gboolean zenity_file_confirm_overwrite;
 
 /* List Dialog Options */
 static gboolean zenity_list_active;
@@ -81,6 +82,7 @@ static gboolean zenity_progress_active;
 static int      zenity_progress_percentage;
 static gboolean zenity_progress_pulsate;
 static gboolean zenity_progress_auto_close;
+static gboolean zenity_progress_auto_kill;
 
 /* Question Dialog Options */
 static gboolean zenity_question_active;
@@ -163,7 +165,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "day",
@@ -172,7 +174,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_INT,
     &zenity_calendar_day,
     N_("Set the calendar day"),
-    NULL
+    N_("DAY")
   },
   {
     "month",
@@ -181,7 +183,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_INT,
     &zenity_calendar_month,
     N_("Set the calendar month"),
-    NULL
+    N_("MONTH")
   },
   {
     "year",
@@ -190,7 +192,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_INT,
     &zenity_calendar_year,
     N_("Set the calendar year"),
-    NULL
+    N_("YEAR")
   },
   {
     "date-format",
@@ -199,7 +201,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_calendar_date_format,
     N_("Set the format for the returned date"),
-    NULL
+    N_("PATTERN")
   },
   {
     NULL
@@ -223,7 +225,7 @@ static GOptionEntry entry_options[] = {
     G_OPTION_ARG_STRING | G_OPTION_FLAG_NOALIAS,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "entry-text",
@@ -232,7 +234,7 @@ static GOptionEntry entry_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_entry_entry_text,
     N_("Set the entry text"),
-    NULL
+    N_("TEXT")
   },
   {
     "hide-text",
@@ -241,7 +243,7 @@ static GOptionEntry entry_options[] = {
     G_OPTION_ARG_NONE,
     &zenity_entry_hide_text,
     N_("Hide the entry text"),
-    NULL
+    N_("TEXT")
   },
   { 
     NULL 
@@ -266,7 +268,7 @@ static GOptionEntry error_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -299,7 +301,7 @@ static GOptionEntry info_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -370,6 +372,15 @@ static GOptionEntry file_selection_options[] = {
     N_("Set output separator character"),
     N_("SEPARATOR")
   },
+  {
+    "confirm-overwrite",
+    '\0',
+    0,
+    G_OPTION_ARG_NONE,
+    &zenity_file_confirm_overwrite,
+    N_("Confirm file selection if filename already exists"),
+    NULL
+  },
   { 
     NULL 
   } 
@@ -392,7 +403,7 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "column",
@@ -401,7 +412,7 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING_ARRAY,
     &zenity_list_columns,
     N_("Set the column header"),
-    NULL
+    N_("COLUMN")
   },
   {
     "checklist",
@@ -455,7 +466,7 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_list_print_column,
     N_("Print a specific column (Default is 1. 'ALL' can be used to print all columns)"),
-    NULL
+    N_("NUMBER")
   },
   {
     "hide-column",
@@ -464,7 +475,7 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_list_hide_column,
     N_("Hide a specific column"),
-    NULL
+    N_("NUMBER")
   },
   { 
     NULL 
@@ -488,7 +499,7 @@ static GOptionEntry notification_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the notification text"),
-    NULL
+    N_("TEXT")
   },
   {
     "listen",
@@ -521,7 +532,7 @@ static GOptionEntry progress_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "percentage",
@@ -530,7 +541,7 @@ static GOptionEntry progress_options[] = {
     G_OPTION_ARG_INT,
     &zenity_progress_percentage,
     N_("Set initial percentage"),
-    NULL
+    N_("PERCENTAGE")
   },
   {
     "pulsate",
@@ -551,6 +562,16 @@ static GOptionEntry progress_options[] = {
     N_("Dismiss the dialog when 100% has been reached"),
     NULL
   },
+  {
+    "auto-kill",
+    '\0',
+    0,
+    G_OPTION_ARG_NONE,
+    &zenity_progress_auto_kill,
+    /* xgettext: no-c-format */
+    N_("Kill parent process if cancel button is pressed"),
+    NULL
+  },
   { 
     NULL 
   }
@@ -573,7 +594,7 @@ static GOptionEntry question_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -639,7 +660,7 @@ static GOptionEntry warning_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -672,7 +693,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "value",
@@ -681,7 +702,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_value,
     N_("Set initial value"),
-    NULL
+    N_("VALUE")
   },
   {
     "min-value",
@@ -690,7 +711,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_min_value,
     N_("Set minimum value"),
-    NULL
+    N_("VALUE")
   },
   {
     "max-value",
@@ -699,7 +720,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_max_value,
     N_("Set maximum value"),
-    NULL
+    N_("VALUE")
   },
   {
     "step",
@@ -708,7 +729,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_step,
     N_("Set step size"),
-    NULL
+    N_("VALUE")
   },
   {
     "print-partial",
@@ -921,6 +942,7 @@ zenity_file_pre_callback (GOptionContext *context,
   zenity_file_active = FALSE;
   zenity_file_directory = FALSE;
   zenity_file_save = FALSE;
+  zenity_file_confirm_overwrite = FALSE;
 
   return TRUE;
 }
@@ -963,6 +985,7 @@ zenity_progress_pre_callback (GOptionContext *context,
   zenity_progress_percentage = 0;
   zenity_progress_pulsate = FALSE;
   zenity_progress_auto_close = FALSE;
+  zenity_progress_auto_kill = FALSE;
 
   return TRUE;
 }
@@ -1105,7 +1128,7 @@ zenity_entry_post_callback (GOptionContext *context,
 		            GError        **error)
 {
   zenity_option_set_dialog_mode (zenity_entry_active, MODE_ENTRY);
-
+  
   if (results->mode == MODE_ENTRY) {
     results->entry_data->dialog_text = zenity_general_dialog_text;
     results->entry_data->entry_text = zenity_entry_entry_text;
@@ -1170,6 +1193,7 @@ zenity_file_post_callback (GOptionContext *context,
     results->file_data->multi = zenity_general_multiple;
     results->file_data->directory = zenity_file_directory;
     results->file_data->save = zenity_file_save;
+    results->file_data->confirm_overwrite = zenity_file_confirm_overwrite;
     results->file_data->separator = zenity_general_separator;
   } else {
     if (zenity_file_directory)
@@ -1270,6 +1294,7 @@ zenity_progress_post_callback (GOptionContext *context,
     results->progress_data->dialog_text = zenity_general_dialog_text;
     results->progress_data->pulsate = zenity_progress_pulsate;
     results->progress_data->autoclose = zenity_progress_auto_close;
+    results->progress_data->autokill = zenity_progress_auto_kill;
     results->progress_data->percentage = zenity_progress_percentage;
   } else {
     if (zenity_progress_pulsate)
@@ -1283,6 +1308,10 @@ zenity_progress_post_callback (GOptionContext *context,
     if (zenity_progress_auto_close)
       zenity_option_error (zenity_option_get_name (progress_options, &zenity_progress_auto_close),
                            ERROR_SUPPORT);
+                           
+    if (zenity_progress_auto_kill)
+      zenity_option_error (zenity_option_get_name (progress_options, &zenity_progress_auto_kill),
+                           ERROR_SUPPORT);
   }
     
   return TRUE;
